@@ -29,18 +29,18 @@ try {// Load root from config file.  Error if missing or unable to determine api
     alert('missing or corrupt config.js file');
 }
 
-var language = getURLParameter('lang');
+var language = getURLParameter('lang').replace(/\./g,'');
 templid = parseInt(getURLParameter("templid"));
 if (templid == null || isNaN(parseInt(templid))) {   // If no clean template ID, see if we have a default from config.js
-	try {
-		if (typeof(getDefaultTemplateId) == 'function') {
-			templid = getDefaultTemplateId ();
-			if (templid == 0) templid = null;
-		}
-	} catch (e)
-	{
-		log('missing default ID from config file');
-	}
+    try {
+        if (typeof(getDefaultTemplateId) == 'function') {
+            templid = getDefaultTemplateId ();
+            if (templid == 0) templid = null;
+        }
+    } catch (e)
+    {
+        log('missing default ID from config file');
+    }
 }
 if (templid !== null) {
     $('head').append('<link rel="stylesheet" type="text/css" href="./templates/' + templid + '-style.css">');
@@ -61,6 +61,14 @@ $().ready(function () {// Once ready, load templates.
     $('#footer-placeholder').show();
 
     itemid = getURLParameter("email");
+    var option= {
+            resGetPath: 'l10n/__ns__-__lng__.json',
+            debug: debug,
+            detectLngQS: 'lang',
+            fallbackLng: 'en_US',
+            customLoad: loadTranslations
+
+    };
     i18n.init(option, function(t) {
         $('.view').i18n();
         if (root !== undefined) view('login');
@@ -90,10 +98,19 @@ $().ready(function () {// Once ready, load templates.
                 $('#loginHeader').text(i18n.t('Please provide your encryption password'));
                 $('#Password').focus();
             }
+            var newGuest = templid = getURLParameter('newGuest');
+            if (newGuest) {
+                login();
+            }
         }, 'json');
 
         // Language selection listener
         $("#languageSelect").click(loadLanguage);
+        var resetid = getURLParameter('resetid');
+        if (resetid != null) {
+            view('DoResetDiv');
+        }
+
     });
 });
 
@@ -106,6 +123,39 @@ function loadLanguage (ev) {
     window.location.replace(url);
 }
 
+// Load translation for language.  Custom overwrites.
+function fetchTranslations (callback, options) {
+    var requests = [];
+    var custom, translation = {};
+    $.get("l10n/translation-" + language + ".json")
+        .done(function(data) {
+                $.get("l10n/custom-" + language + ".json")
+                .done(function(custdata) {
+                    $.extend(data, custdata);
+                })
+                .always(function () {
+                    callback(data);
+                });
+        })
+        .fail(function () {
+            console.log('Failed to load language ' + language);
+            $.get("l10n/translation-" + options.fallbackLng + ".json")
+                .done(function (data) {
+                    callback(data);
+                })
+                .fail(function (e) {
+                    console.log(e);
+                    alert('Failed to default language');
+                });
+        });
+}
+
+function loadTranslations (lng, ns, options, loadComplete) {
+    fetchTranslations (function (data) {
+        loadComplete(null, data);
+    }, options);
+}
+
 // Load the template.  Format should be cid-template .  Location in template subdirectory
 function getTemplate (templid, template, locationID) {
     $.get('./templates/' + (templid === null ? "" : (templid + "-")) + template, function (data) {
@@ -152,7 +202,7 @@ function login() {
                 return;
             }
             if (data.productName) {
-            	$('head').append('<title>' + data.productName + '</title>');
+                $('head').append('<title>' + data.productName + '</title>');
             }
             if (data.auth === 'Password Needed') {
                 $('#login').hide();
@@ -164,17 +214,23 @@ function login() {
                 return;
             }
             if (data.auth === 'Bad Password' || data.auth === 'No Key') {
+                if (password === '') {
+                    $('#authorizing').hide();
+                    return;  // This was a blank login attempt
+                }
                 //#. Bad username or Password at login
                 $('#ErrorBox').html(i18n.t('Bad username / Password'));
                 $('#ErrorBox').show();
                 $('#Username').show();
                 $('#Password').val('').focus();
                 $('#authorizing').hide();
+                /*
                 if (data.recoveryAvail === false) {
-                	$('.forgot').hide();
+                    $('.forgot').hide();
                 } else {
-                	$('.forgot').show();
+                    $('.forgot').show();
                 }
+                */
                 return;
             }
 
@@ -185,9 +241,11 @@ function login() {
                 $('#Password').hide();
                 $('#LoginButton').hide();
                 $('#authorizing').hide();
+                /*
                 if (data.recoveryAvail === false) {
-                	$('.forgot').hide();
+                    $('.forgot').hide();
                 }
+                */
                 return;
             }
             if (data.auth === 'not found') {
@@ -196,6 +254,18 @@ function login() {
                 $('#authorizing').hide();
                 return;
             }
+            if (data.auth === 'new') {
+                view('newUser');
+                $('#welcome').text(i18n.t('Welcome to $s').replace('$s', data.productName));
+                if (data.pin) {
+                    $('#pinDiv').show();
+                }
+                settings = data.settings;
+                if (data.settings && data.settings.noRecovery) {
+                    $('#newQA').hide();
+                }
+                return;
+            }
             noRecovery = data.settings.noRecovery;
             if (data.auth.length > 20) {
                 okLogin(data, action);
@@ -279,10 +349,105 @@ function loginPin() {
     });
 }
 
+function firstPassChange() {
+    var newpass = $('#firstpass').val();
+    var newpass2 = $('#firstpass2').val();
+    if (newpass !== newpass2) {
+        $('#firstErrorDiv').text(i18n.t('Passwords not equal'));
+        $('#firstErrorDiv').show();
+        $('#firstpass').focus();
+        return;
+    }
+    var question = $('#newQuestion').val();
+    var answer = $('#newAnswer').val();
+    if (settings.noRecovery === false) {
+        if (answer.length < 2) {
+            $('#firstErrorDiv').text(i18n.t('Answer required for password reset option'));
+            $('#firstErrorDiv').show();
+            $('#newAnswer').focus();
+            return;
+        }
+    }
+    var itemId = getURLParameter("email");
+    var pin = $('#newpin').val();
+    var passdata = {
+            newpass: newpass,
+            question: question,
+            answer: answer,
+            pin: pin,
+            email: $('#Username').val(),
+            itemId: itemId
+        };
+    showWait();
+        $.ajax({
+            url: root + 'oxguard/guest?action=firstpass',
+            type:'POST',
+            data: JSON.stringify(passdata),
+            contentType:'application/json; charset=utf-8',
+            success: function (data) {
+                $('#firstErrorDiv').hide();
+                if (data instanceof Array) data = data[0];
+                if (data && data.error) {
+                    hideWait();
+                    if (data.code === 'GRD-CHANGE-PW-0002') {
+                        $('#firstErrorDiv').text(i18n.t('PIN invalid or missing'));
+                        $('#firstErrorDiv').show();
+                        $('#newpin').focus();
+                        return;
+                    }
+                    if (data.code === 'GRD-CHANGE-PW-0001') {
+                        $('#firstErrorDiv').text(i18n.t('Password Length Too Short'));
+                        $('#firstErrorDiv').show();
+                        $('#firstpass').focus();
+                        return;
+                    }
+                    alert (data.error + ' ' + data.error_desc);
+                    return;
+                }
+                if (data.auth && data.auth.length > 20) {
+                    auth = data.auth;
+                    okLogin(data);
+                }
+            }
+        })
+        .fail(function (data) {
+            $('#firstErrorDiv').text(i18n.t('Problem connecting with the server'));
+            $('#firstErrorDiv').show();
+            alert(data);
+        })
+        .always(function () {
+            hideWait();
+        });
+
+}
+
 function showChangepass() {
     view('NewPassword');
 }
 
+function showWait() {
+    $('#waitDiv').show();
+}
+
+function hideWait() {
+    $('#waitDiv').hide();
+}
+
+function comparePass(pass1, pass2, err1, err2) {
+    var val1 = $('#' + pass1).val();
+    var val2 = $('#' + pass2).val();
+    if ((val1 != val2) && (val2 != '')) {
+        $('#' + err2).text(i18n.t('Passwords do not match'));
+    } else {
+        $('#' + err2).text('');
+    }
+    if (settings.min_password_length && (val1.length < settings.min_password_length)) {
+        $('#' + err1).text(i18n.t('Too short'));
+    } else {
+        $('#' + err1).text('');
+    }
+}
+
 // Change the oxguard password
 function changePass() {
     var pass1 = $('#new1').val();
@@ -307,20 +472,24 @@ function changePass() {
         success: function (data) {
             if (typeof data === 'string') data = $.parseJSON(data);
             log('success ', data);
-            if (data.auth.length > 20) {
+            if (data.auth && data.auth.length > 20) {
                 auth = data.auth;
                 $('#new1').val('');
                 $('#new2').val('');
                 $('#old').val('');
                 $('#ChangeError').removeClass('alert-danger').addClass('alert-success');
                 $('#ChangeError').html(i18n.t("Password Changed"));
-            $('#ChangeError').show();
+                $('#ChangeError').show();
                 window.setTimeout (function() {
-            $('#ChangeError').html();
-                    $('#ChangeError').hide();
-            view("Reader");
+                    $('#ChangeError').html();
+                        $('#ChangeError').hide();
+                        view("Reader");
                 }, 2000);
-
+            }
+            if (data instanceof Array) data = data[0];
+            if (data && data.error) {
+                $('#ChangeError').html(i18n.t("Failed to change password" + ': ') + data.error);
+                $('#ChangeError').removeClass('alert-success').addClass('alert-danger').show();
             }
         }
 
@@ -499,8 +668,8 @@ function openreader(ldata, extra) {
                     }
                     $('#firstChangePassDiv').show();
                     if (noRecovery) {
-                    	$('.qaDiv').hide();
-                    	$('.passchange').css('height', '50%').css('min-height', '400px');
+                        $('.qaDiv').hide();
+                        $('.passchange').css('height', '50%').css('min-height', '400px');
                     }
                 },2000);
             }
@@ -543,19 +712,19 @@ function openreader(ldata, extra) {
 }
 
 function getSignature (data) {
-	var signedicon = '';
-	if (data.results) {
-		if (data.results.signature === true) {
-			if (data.results.verified === true) {
-				// valid signature
-				signedicon = $('<i class="oxguard_icon_fa fa-pencil-square-o fa oxguard_signed" aria-hidden="true" title="' + i18n.t('This Email was signed and verified') + '"/>');
-			} else {
-				// invalid signature
-				$('<i class="oxguard_icon_fa_alert fa-pencil-square fa oxguard_signed" aria-hidden="true" title="' + i18n.t('This Email was signed and failed verification') + '"/>');
-			}
-		}
-	}
-	return (signedicon);
+    var signedicon = '';
+    if (data.results) {
+        if (data.results.signature === true) {
+            if (data.results.verified === true) {
+                // valid signature
+                signedicon = $('<i class="oxguard_icon_fa fa-pencil-square-o fa oxguard_signed" aria-hidden="true" title="' + i18n.t('This Email was signed and verified') + '"/>');
+            } else {
+                // invalid signature
+                $('<i class="oxguard_icon_fa_alert fa-pencil-square fa oxguard_signed" aria-hidden="true" title="' + i18n.t('This Email was signed and failed verification') + '"/>');
+            }
+        }
+    }
+    return (signedicon);
 }
 
 function fail(alerttype)
@@ -588,11 +757,11 @@ function replace_content_id (content, data, item) {
 }
 
 function getFullRoot () {
-	// If root already has domain, just return
-	if (root.indexOf('http') > -1) {
-		return root;
-	}
-	return 'https://' + document.domain + '/' + root;
+    // If root already has domain, just return
+    if (root.indexOf('http') > -1) {
+        return root;
+    }
+    return 'https://' + document.domain + '/' + root;
 }
 
 // Get base url
@@ -1058,9 +1227,10 @@ function forgotPass() {
             }
             $('#wait').hide();
             if (data.trim() === 'nr') {
-            	$('#ForgotError').html(i18n.t("Password reset not available for this account"));
-            	$('#ForgotError').show();
-            	return;
+                //$('#ForgotError').html(i18n.t("Password reset not available for this account"));
+                //$('#ForgotError').show();
+                view('Reset');
+                return;
             }
             if ((data.trim() === "null") || (data.trim() === "PIN")) {// If no recovery answer yet set up, reset
                 forgotPass2()
@@ -1113,14 +1283,76 @@ function forgotPass2() {
         $('#wait').hide();
         log("Forgot2 fail ", data);
         if (data.responseText.indexOf('no recovery') > 0) {
-        	$('#ForgotError2').html(i18n.t("Password reset not available for this account"));
+            $('#ForgotError2').html(i18n.t("Password reset not available for this account"));
         } else {
-        	$('#ForgotError2').html(i18n.t("Failed to change password"));
+            $('#ForgotError2').html(i18n.t("Failed to change password"));
         }
         $('#ForgotError2').show();
     });
 }
 
+// Function to send account reset request
+function resetAccount () {
+    view('ResetResultDiv');
+    var email = $('#EmailAddr').val();
+    var url = root + 'oxguard/guest?action=resetaccount&user=' + email + '&templid=' + templid;
+    $.get(url, function (data) {
+        if (data instanceof Array) data = data[0];
+        log("reset", data);
+        if (data && data.error) {
+            $('#ResetResult').text(data.error + ' ' + data.error_desc);
+        } else {
+            if (data.data) {
+                $('#ResetResult').html(i18n.t("A verification email has been sent  Please check your inbox and follow the instructions in the email"));
+            } else {
+                $('#ResetResult').text(i18n.t("Unkown Error"));
+            }
+        }
+    });
+}
+
+function doResetAccount() {
+    var pass1 = $('#resetnew1').val();
+    var pass2 = $('#resetnew2').val();
+    if (pass1 != pass2) {
+        $('#resetError').text(i18n.t('Passwords not equal'));
+        return;
+    }
+    if (pass1.length < 4) {
+        $('#resetError').text(i18n.t('Passwords too short'));
+    }
+    $('#resetError').text('');
+    var resetid = getURLParameter('resetid');
+    var email = getURLParameter('user');
+    var data = {
+            email: email,
+            resetid: resetid,
+            password: pass1
+    }
+    var url = root + 'oxguard/guest?action=doresetaccount';
+       $.ajax({
+            url: url,
+            type: "POST",
+            data: JSON.stringify(data),
+            contentType:'application/json; charset=utf-8',
+            processData: false,  // tell jQuery not to process the data
+            contentType: false,   // tell jQuery not to set contentType
+            success: function(data){
+                if (data instanceof Array) data = data[0];
+                if (data && data.error) {
+                    $('#resetErrorDiv').show();
+                    $('#resetErrorBox').text(data.error);
+                } else {
+                    $('#resetErrorDiv').hide();
+                    $('#ResetStep1').hide();
+                    $('#ResetStep2').show();
+                }
+            },
+            error: function (XMLHttpRequest, textStatus, errorThrown) {
+            }
+       });
+}
+
 function view (element) {
     $('.view').hide();
     if (element !== undefined)
@@ -1298,7 +1530,26 @@ function updateCheckBox () {
     } else $('#inline').prop('checked', false);
     if (settings.direct) {
         $('#direct').prop('checked', true);
-    } else $('#direct').prop('checked', false);
+        $('#inlineDiv').show();
+    } else {
+        $('#direct').prop('checked', false);
+        $('#inlineDiv').hide();
+    }
+}
+
+function showPGPDirect () {
+    if ($('#direct').is('::checked') !== true) {
+        $('.mask').show();
+        $('.pgpDirect').show();
+        return false;
+    }
+}
+
+function setDirect() {
+    $('#direct').prop('checked', true);
+    updateSettings();
+    $('.mask').hide();
+    $('.pgpDirect').hide();
 }
 
 function updateSettings () {
@@ -1311,6 +1562,10 @@ function updateSettings () {
     settings.inline = inline;
     settings.direct = direct;
 
+    if (!direct) {
+        $('#inlineDiv').hide(); // hide inline data if not direct
+    } else $('#inlineDiv').show();
+
     var json = {
             id : userid,
             cid : cid,
@@ -1409,7 +1664,7 @@ function downloadKeys() {
 }
 
 function logOut () {
-    $.get(root + '/oxguard/login?action=logout')
+    $.get(root + '/oxguard/login?action=logout&auth=' + encodeURIComponent(auth))
     .done(function () {
         view('logout');
     })
